==> owlapi-distribution-4.5.6-sources.jar: org/semanticweb/owlapi/model/OWLAxiomVisitorEx.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.model;

import javax.annotation.Nonnull;

/**
 * An interface for objects that can accept visits from axioms. (See the <a
 * href="http://en.wikipedia.org/wiki/Visitor_pattern">Visitor Patterns</a>)
 * 
 * @author Matthew Horridge, The University Of Manchester, Bio-Health
 *         Informatics Group
 * @since 2.2.0
 * @param <O>
 *        visitor return type
 */
public interface OWLAxiomVisitorEx<O> extends OWLAnnotationAxiomVisitorEx<O>,
        OWLLogicalAxiomVisitorEx<O> {

    /**
     * visit OWLDeclarationAxiom type
     * 
     * @param axiom
     *        axiom to visit
     * @return visitor value
     */
    @Nonnull
    O visit(@Nonnull OWLDeclarationAxiom axiom);

    /**
     * visit OWLDatatypeDefinitionAxiom type
     * 
     * @param axiom
     *        axiom to visit
     * @return visitor value
     */
    @Nonnull
    O visit(@Nonnull OWLDatatypeDefinitionAxiom axiom);
}

==> owlapi-distribution-5.0.5-sources.jar: org/semanticweb/owlapi/model/OWLAxiomVisitorEx.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.model;

/**
 * An interface for objects that can accept visits from axioms. (See the
 * <a href="http://en.wikipedia.org/wiki/Visitor_pattern">Visitor Patterns</a>)
 * 
 * @author Matthew Horridge, The University Of Manchester, Bio-Health
 *         Informatics Group
 * @since 2.2.0
 * @param <O>
 *        visitor return type
 */
public interface OWLAxiomVisitorEx<O> extends OWLAnnotationAxiomVisitorEx<O>, OWLLogicalAxiomVisitorEx<O> {

    /**
     * visit OWLDeclarationAxiom type
     * 
     * @param axiom
     *        axiom to visit
     * @return visitor value
     */
    default O visit(OWLDeclarationAxiom axiom) {
        return doDefault(axiom);
    }

    /**
     * visit OWLDatatypeDefinitionAxiom type
     * 
     * @param axiom
     *        axiom to visit
     * @return visitor value
     */
    default O visit(OWLDatatypeDefinitionAxiom axiom) {
        return doDefault(axiom);
    }
}
